@@ -1,6 +1,7 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.SummaryVariables import SummaryVariables as vars
 
-class Summary:
+class Summary(FTSProtocolObject):
     def __init__(self):
         self.INTAG = vars().INTAG
 
