@@ -11,10 +11,10 @@ class ExCheckChecklist(Base):
     __tablename__ = "ExCheckChecklist"
     PrimaryKey = Column(Integer, primary_key = True, autoincrement=True)
     startTime = Column(DateTime)
-    creatorUid = Column(String)
-    description = Column(String)
-    name = Column(String)
-    callsign = Column(String)
-    uid = Column(String)
-    filename = Column(String)
+    creatorUid = Column(String(100))
+    description = Column(String(100))
+    name = Column(String(100))
+    callsign = Column(String(100))
+    uid = Column(String(100))
+    filename = Column(String(100))
     template_id = Column(Integer, ForeignKey('ExCheck.PrimaryKey'))
\ No newline at end of file
